#!/usr/bin/perl

# SPDX-License-Identifier: MPL-2.0
# SPDX-FileCopyrightText: 2025 Collabora Ltd.
# SPDX-FileCopyrightText: 2025 Dylan Aïssi <dylan.aissi@collabora.com>

use warnings;
use strict;
use Debian::Debhelper::Dh_Lib;

insert_before("dh_strip", "dh_setup_copyright");

1;
